<?php

namespace Crm\School\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Crm\School\Http\Resources\SchoolResource;
use Crm\School\Http\Resources\SchoolsCollection;
use Crm\School\Scopes\BlockPublicScope;
use Crm\School\Models\Block;

class BlockPublicController extends BaseController
{

    /**
     * Show block's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Block::pushScope(new RequestScope())
            ->pushScope(new BlockPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $blocks = new BlocksCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('school::block.names'))
            ->view('school::public.block.index')
            ->data(compact('blocks', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show block.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Block::findBySlug($slug);
        $data = new BlockResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('school::block.name'))
            ->view('school::public.block.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
