<?php

namespace Crm\School\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Crm\School\Http\Resources\SchoolResource;
use Crm\School\Http\Resources\SchoolsCollection;
use Crm\School\Scopes\NoticePublicScope;
use Crm\School\Models\Notice;

class NoticePublicController extends BaseController
{

    /**
     * Show notice's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Notice::pushScope(new RequestScope())
            ->pushScope(new NoticePublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $notices = new NoticesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('school::notice.names'))
            ->view('school::public.notice.index')
            ->data(compact('notices', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show notice.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Notice::findBySlug($slug);
        $data = new NoticeResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('school::notice.name'))
            ->view('school::public.notice.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
