<?php

namespace Crm\School\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\School\Models\Block;

class BlockPolicy
{


    /**
     * Determine if the given user can view the block.
     *
     * @param Authenticatable $user
     * @param Block $block
     *
     * @return bool
     */
    public function view(Authenticatable $user, Block $block)
    {
        if ($authUser->canDo('school.block.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $block->is_owner;
    }

    /**
     * Determine if the given user can create a block.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('school.block.create');
    }

    /**
     * Determine if the given user can update the given block.
     *
     * @param Authenticatable $user
     * @param Block $block
     *
     * @return bool
     */
    public function update(Authenticatable $user, Block $block)
    {
        if ($user->canDo('school.block.edit') && $user->isAdmin()) {
            return true;
        }

        return $block->is_owner;
    }

    /**
     * Determine if the given user can delete the given block.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Block $block)
    {
        return $block->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
