<?php

namespace Crm\School\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\School\Models\Download;

class DownloadPolicy
{


    /**
     * Determine if the given user can view the download.
     *
     * @param Authenticatable $user
     * @param Download $download
     *
     * @return bool
     */
    public function view(Authenticatable $user, Download $download)
    {
        if ($authUser->canDo('school.download.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $download->is_owner;
    }

    /**
     * Determine if the given user can create a download.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('school.download.create');
    }

    /**
     * Determine if the given user can update the given download.
     *
     * @param Authenticatable $user
     * @param Download $download
     *
     * @return bool
     */
    public function update(Authenticatable $user, Download $download)
    {
        if ($user->canDo('school.download.edit') && $user->isAdmin()) {
            return true;
        }

        return $download->is_owner;
    }

    /**
     * Determine if the given user can delete the given download.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Download $download)
    {
        return $download->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
