<?php

namespace Crm\School\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\School\Models\Notice;

class NoticePolicy
{


    /**
     * Determine if the given user can view the notice.
     *
     * @param Authenticatable $user
     * @param Notice $notice
     *
     * @return bool
     */
    public function view(Authenticatable $user, Notice $notice)
    {
        if ($authUser->canDo('school.notice.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $notice->is_owner;
    }

    /**
     * Determine if the given user can create a notice.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('school.notice.create');
    }

    /**
     * Determine if the given user can update the given notice.
     *
     * @param Authenticatable $user
     * @param Notice $notice
     *
     * @return bool
     */
    public function update(Authenticatable $user, Notice $notice)
    {
        if ($user->canDo('school.notice.edit') && $user->isAdmin()) {
            return true;
        }

        return $notice->is_owner;
    }

    /**
     * Determine if the given user can delete the given notice.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Notice $notice)
    {
        return $notice->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
