<?php

namespace Crm\School\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Crm\School\Models\Block;
use Crm\School\Models\Download;
use Crm\School\Models\Gallery;
use Crm\School\Models\Notice;
use Crm\School\Models\Slider;
use Crm\School\Models\Testimonial;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Crm\School\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/school/block/*')) {
            Route::bind('block', function ($block) {
                return Block::findorNew($block);
            });
        }
        if (Request::is('*/school/download/*')) {
            Route::bind('download', function ($download) {
                return Download::findorNew($download);
            });
        }
        if (Request::is('*/school/gallery/*')) {
            Route::bind('gallery', function ($gallery) {
                return Gallery::findorNew($gallery);
            });
        }
        if (Request::is('*/school/notice/*')) {
            Route::bind('notice', function ($notice) {
                return Notice::findorNew($notice);
            });
        }
        if (Request::is('*/school/slider/*')) {
            Route::bind('slider', function ($slider) {
                return Slider::findorNew($slider);
            });
        }
        if (Request::is('*/school/testimonial/*')) {
            Route::bind('testimonial', function ($testimonial) {
                return Testimonial::findorNew($testimonial);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
