<?php

namespace Crm\School\Providers;

use Illuminate\Support\ServiceProvider;
use Crm\School\Schools;

class SchoolServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'school');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'school');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Crm\School\Providers\AuthServiceProvider::class);
        $this->app->register(\Crm\School\Providers\RouteServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('crm.school', function($app)
        {
            return $this->app->make(School::class);
        });
    }

    /**
     * Merges user's and school's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'crm.school'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/block.php', 'crm.school.block'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/download.php', 'crm.school.download'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/gallery.php', 'crm.school.gallery'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/notice.php', 'crm.school.notice'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/slider.php', 'crm.school.slider'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/testimonial.php', 'crm.school.testimonial'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['crm.school'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('crm/school')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/school')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/school')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
